pub enum Error {
Open(OpenError),
Configure(ConfigureError),
Prepare(PrepareError),
Bind(BindError),
Step(StepError),
Decode(DecodeError),
Reset(ResetError),
}Variants
Open(OpenError)
an error when failed to open a database
Configure(ConfigureError)
an error when failed to configure database
Prepare(PrepareError)
an error when failed to create prepared statement
Bind(BindError)
an error when failed to bind value to parameter
Step(StepError)
an error when failed to get the next row
Decode(DecodeError)
an error when failed to decode value
Reset(ResetError)
an error when failed to reset or clear binding prepared statement