pub enum OpenError {
NotSerializeMode,
String(StringError),
Database(DatabaseError),
}Expand description
An error when failed to open a database connection
Variants
NotSerializeMode
Sqlite is not in Serialized mode
String(StringError)
An error when failed to convert rust to sqlite string
Database(DatabaseError)
An error returned from database
Implementations
Sourceimpl OpenError
impl OpenError
Sourcepub fn is_busy(&self) -> bool
pub fn is_busy(&self) -> bool
Returns true if the error is a SQLITE_BUSY.
SQLITE_BUSY occur when the database engine was unable to acquire the database locks it needs to do its job.
If the statement is a COMMIT or occurs outside of an explicit transaction, then you can retry the statement. If the statement is not a COMMIT and occurs within an explicit transaction then you should rollback the transaction before continuing.